#ifndef NT2_INCLUDE_FUNCTIONS_EXPCDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EXPCDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/expcdf.hpp>

#endif
